@@ -6,9 +6,9 @@ use warnings;
 use Log::ger;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2023-07-25'; # DATE
+our $DATE = '2023-08-06'; # DATE
 our $DIST = 'App-CSVUtils'; # DIST
-our $VERSION = '1.030'; # VERSION
+our $VERSION = '1.031'; # VERSION
 
 use App::CSVUtils qw(gen_csv_util);
 
@@ -64,7 +64,7 @@ _
         my $r = shift;
 
         for my $field (@{ $r->{input_fields} }) {
-            if ($field =~ /name/i && !defined($r->{fields_for}{N})) {
+            if ($field =~ /name|nama/i && !defined($r->{fields_for}{N})) {
                 log_info "Will be using field '$field' for VCF field 'N' (name)";
                 $r->{fields_for}{N} = $field;
             }
@@ -72,7 +72,7 @@ _
                 log_info "Will be using field '$field' for VCF field 'EMAIL'";
                 $r->{fields_for}{EMAIL} = $field;
             }
-            if ($field =~ /cell|hp|phone|wa|whatsapp/i && !defined($r->{fields_for}{CELL})) {
+            if ($field =~ /cell|hp|phone|wa|whatsapp|te?le?[fp](on)?/i && !defined($r->{fields_for}{CELL})) {
                 log_info "Will be using field '$field' for VCF field 'CELL' (cellular phone)";
                 $r->{fields_for}{CELL} = $field;
             }
@@ -123,7 +123,7 @@ App::CSVUtils::csv2vcf - Create a VCF from selected fields of the CSV
 
 =head1 VERSION
 
-This document describes version 1.030 of App::CSVUtils::csv2vcf (from Perl distribution App-CSVUtils), released on 2023-07-25.
+This document describes version 1.031 of App::CSVUtils::csv2vcf (from Perl distribution App-CSVUtils), released on 2023-08-06.
 
 =head1 FUNCTIONS
 
